﻿-----------------------------------------------------------------------------

local Roster = AceLibrary("Roster-2.1")

-----------------------------------------------------------------------------

local AssessmentCustomColorType = Assessment:NewModule("CustomColorType", "AceEvent-2.0")
AssessmentCustomColorType.db = Assessment:AcquireDBNamespace("CustomColorType")
Assessment:RegisterDefaults("CustomColorType", "profile",
{
	customColors =
	{
	}
})

local L = AceLibrary("AceLocale-2.2"):new("AssessmentCustomColorType")
L:RegisterTranslations("enUS", function() return {
	["Custom Colors"] = true,
	["Custom color options."] = true,
} end)

L:RegisterTranslations("zhCN", function() return {
	["Custom Colors"] = "自定义颜色",
	["Custom color options."] = "自定义颜色的相关选项",
} end)

L:RegisterTranslations("zhTW", function() return {
	["Custom Colors"] = "自定義顏色",
	["Custom color options."] = "自定義顏色的相關選項",
} end)


L:RegisterTranslations("koKR", function() return {
	["Custom Colors"] = "사용자 색상",
	["Custom color options."] = "사용자 색상 설정입니다.",
} end)

L:RegisterTranslations("frFR", function() return {
	["Custom Colors"] = "Couleurs Personnalis\195\169es",
	["Custom color options."] = "Option de personnalisation des couleurs",
} end)

-----------------------------------------------------------------------------

local profile

-----------------------------------------------------------------------------

Assessment.ColorType.Custom = 
{
	method = function(fightData, data)
				if not profile.customColors[data.key] then
					profile.customColors[data.key] = { 1, 1, 0, 1 }
					AssessmentCustomColorType:AddColor(data.key)
				end
				return profile.customColors[data.key]
			 end,
	description = L["Custom Colors"]
}

-----------------------------------------------------------------------------

local function colorGet(passValue)
	return unpack(AssessmentCustomColorType.db.profile.customColors[passValue])
end

local function colorSet(passValue, r, g, b, a)
	AssessmentCustomColorType.db.profile.customColors[passValue] = { r, g, b, a }
	Assessment:RedrawAll()
end

-----------------------------------------------------------------------------

function AssessmentCustomColorType:OnInitialize()
	profile = self.db.profile
end

function AssessmentCustomColorType:OnEnable()
	for k,v in pairs(self.db.profile.customColors) do
		self:AddColor(k)
	end
end

-----------------------------------------------------------------------------

Assessment.Options.args.data.args.customColors =
{
	type = "group",
	name = L["Custom Colors"],
	desc = L["Custom color options."],
	order = 100,
	args = { },
}

-----------------------------------------------------------------------------

function AssessmentCustomColorType:AddColor(name)
	Assessment.Options.args.data.args.customColors.args[name] =
	{
		type = "color",
		name = name,
		desc = name,
		get = colorGet,
		set = colorSet,
		passValue = name,
		hasAlpha = true,
	}
end

-----------------------------------------------------------------------------
